@@ -20,9 +20,9 @@
  */
 #include <stdint.h>
 #include <libzrtpcpp/ZrtpConfigure.h>
-//                                  1
-//                         1234567890123456
-char clientId[] =    "GNU ZRTP 1.5.4  "; // 16 chars max.
+//                             1
+//                    1234567890123456
+char clientId[] =    "GNU ZRTP 1.6.0  "; // 16 chars max.
 char zrtpVersion[] = "1.10";             // must be 4 chars
 /**
  *
@@ -77,10 +77,10 @@ char two1[] = "2FS1";
 
 const char* mandatoryCipher = aes1;
 
-char dh2k[] =  "DH2k";
-              // "EC25"
+char dh2k[] = "DH2k";
+char ec25[] = "EC25";
 char dh3k[] = "DH3k";
-              // "EC38"
+char ec38[] = "EC38";
 char mult[] = "Mult";
 const char* mandatoryPubKey = dh3k;
 
